/**
 * @copyright 2020 {@link http://infiniteautomation.com|Infinite Automation Systems, Inc.} All rights reserved.
 * @author Luis Güette
 */

define([
    'angular',
    'require',

    './pages/overview/overview.js',

    './components/map/map.js',
    './components/selectedUnitCard/selectedUnitCard.js',
    './components/unitsTable/unitsTable.js',
    './components/kpiIndicators/kpiIndicators.js',
    './components/energyChart/energyChart.js',
    './components/alarmList/alarmList.js',

    './services/unit.js'
], (
    angular,
    require,
    overview,
    map,
    selectedUnitCard,
    unitsTable,
    kpiIndicators,
    energyChart,
    alarmList,
    unitService
) => {
    'use strict';

    const hvacModule = angular
        .module('hvacModule', ['maUiApp'])
        .component('hvacOverview', overview)
        .component('hvacMap', map)
        .component('hvacSelectedUnitCard', selectedUnitCard)
        .component('hvacUnitsTable', unitsTable)
        .component('hvacKpiIndicators', kpiIndicators)
        .component('hvacAlarmList', alarmList)
        .component('hvacEnergyChart', energyChart)

        .factory('hvacUnit', unitService);

    hvacModule.config([
        'maUiMenuProvider',
        (maUiMenuProvider) => {
            maUiMenuProvider.registerMenuItems([
                {
                    name: 'ui.overview',
                    url: '/overview',
                    menuIcon: 'map',
                    template: '<hvac-overview></hvac-overview>',
                    menuText: 'Overview',
                    weight: 100,
                    params: {
                        dateBar: {
                            rollupControls: true
                        }
                    }
                },
            ]);
        }
    ]);

    return hvacModule;
}); // define
